@@ -3,35 +3,55 @@
 from pyatcommand import AtClient, AtTimeout
 
 from .common import (
-    NetInfo,
+    BeamStateIdp,
     BeamType,
+    BeamTypeIdp,
+    BeamTypeOgx,
+    ControlStateIdp,
     DataFormat,
     EventNotification,
+    GeoBeam,
     GnssMode,
+    GnssModeQuectel,
+    GnssModeSkywave,
+    LastErrorCode,
+    MessagePriorityIdp,
     MessageState,
     MessageStateIdp,
     MessageStateOgx,
+    MessageTypeOgx,
     ModemManufacturer,
     ModemModel,
+    NetInfo,
     NetworkProtocol,
     NetworkState,
+    NetworkStateOgx,
     OperatingMode,
     PowerMode,
+    SatelliteId,
+    ServiceClassOgx,
+    SignalLevelIdp,
     SignalQuality,
     WakeupInterval,
     WakeupIntervalIdp,
     WakeupIntervalOgx,
 )
+from .loader import clone_and_load_modem_classes, mutate_modem
 from .location import GnssFixQuality, GnssFixType, GnssLocation, GnssSatelliteInfo
 from .message import IotNanoMessage, MoMessage, MtMessage
 from .modem import SatelliteModem
-from .loader import load_modem_class, clone_and_load_modem_classes
 
 __all__ = [
+    'AtClient',
+    'AtTimeout',
+    'LastErrorCode',
     'SatelliteModem',
     'ModemManufacturer',
     'ModemModel',
     'BeamType',
+    'BeamTypeIdp',
+    'BeamStateIdp',
+    'BeamTypeOgx',
     'IotNanoMessage',
     'MessageState',
     'MessageStateIdp',
@@ -39,9 +59,8 @@ __all__ = [
     'MoMessage',
     'MtMessage',
     'NetworkProtocol',
+    'ServiceClassOgx',
     'NetworkState',
-    'AtClient',
-    'AtTimeout',
     'SignalQuality',
     'NetInfo',
     'DataFormat',
@@ -56,6 +75,15 @@ __all__ = [
     'GnssFixQuality',
     'GnssSatelliteInfo',
     'OperatingMode',
-    'load_modem_class',
+    'ControlStateIdp',
+    'NetworkStateOgx',
+    'MessagePriorityIdp',
+    'MessageTypeOgx',
+    'GnssModeSkywave',
+    'GnssModeQuectel',
+    'SignalLevelIdp',
+    'GeoBeam',
+    'SatelliteId',
     'clone_and_load_modem_classes',
+    'mutate_modem',
 ]
