@@ -120,6 +120,7 @@ def mutate_modem(modem: SatelliteModem, **kwargs) -> SatelliteModem:
         modem (SatelliteModem): The base/unknown modem.
         **module (module): The module containing the subclass python files.
             Downloaded files from GitHub will be stored here.
+        **mixin (SatelliteModem): Optional mixin extension subclass to apply.
     
     Returns:
         Subclass of SatelliteModem.
@@ -175,7 +176,16 @@ def mutate_modem(modem: SatelliteModem, **kwargs) -> SatelliteModem:
                 # Disconnect for state prior to mutation
                 if not was_connected:
                     modem.disconnect()
-                modem.__class__ = candidate
+                mixin = kwargs.get('mixin')
+                if mixin and issubclass(mixin, SatelliteModem):
+                    Extended = type(
+                        f'Extended{candidate.__name__}',
+                        (candidate, mixin),
+                        {}
+                    )
+                    modem.__class__ = Extended
+                else:
+                    modem.__class__ = candidate
                 modem._post_mutate()
                 return modem
     # Fall-through
